==================================
Project Governance
==================================

This document informally outlines the organizational structure governing the
Pulsar code base hosted at https://github.com/galaxyproject/pulsar. This
governance extends to code-related activities of this repository such as
releases and packaging and related projects. This governance does not include
any other Galaxy-related projects belonging to the `galaxyproject
<https://github.com/galaxyproject/>`__ organization on GitHub.

Benevolent Dictator for Now (BDFN)
===================================

John Chilton (@jmchilton) is the benevolent dictator for now (BDFN) and is solely
responsible for setting project policy. The BDFN is responsible for maintaining
the trust of the developer community and so should be consistent and
transparent in decision making processes and request comment and build
consensus whenever possible.

The BDFN position only exists because the developers of the project believe it
is currently too small to support full and open governance at this time. In
order to keep things evolving quickly, it is better to keep procedures and
process to a minimum and centralize important decisions with a trusted
developer. The BDFN is explicitly meant to be replaced with a more formal and
democratice process if the project grows to a sufficient size or importance.

The *committers* group is the group of trusted developers and advocates who
manage the Pulsar code base. They assume many roles required to achieve
the project's goals, especially those that require a high level of trust.

The BDFN will add committers as they see fit, usually after a few successful
pull requests. Committers may commit directly or merge pull requests at their
discretion, but everyone (including the BDFN) should open pull requests for
larger changes.

In order to encourage a shared sense of ownership and openness, any committer
may decide at any time to request a open governance model for the project be
established and the BDFN must replace this informal policy with a more formal
one and work with the project committers to establish a consensus on these
procedures.

Committers
==============================

- John Chilton (`@jmchilton <https://github.com/jmchilton/>`__)
- Nate Coraor (`@natefoo <https://github.com/natefoo/>`__)
- Helena Rasche (`@hexylena <https://github.com/hexylena/>`__)
- Marius van den Beek (`@mvdbeek <https://github.com/mvdbeek/>`__)
